@@ -31,12 +31,18 @@ THE SOFTWARE.
 namespace Ogre {
 namespace RTShader {
 
-String CGProgramWriter::TargetLanguage = "cg";
+String CGProgramWriter::TargetLanguage = "hlsl";
 
 //-----------------------------------------------------------------------
 CGProgramWriter::CGProgramWriter()
 {
     initializeStringMaps();
+
+    if(GpuProgramManager::getSingleton().isSyntaxSupported("ps_4_0"))
+    {
+        mGpuConstTypeMap[GCT_SAMPLER2DARRAY] = "Sampler2DArray";
+        mGpuConstTypeMap[GCT_SAMPLER2DSHADOW] = "Sampler2DShadow";
+    }
 }
 
 //-----------------------------------------------------------------------
@@ -123,6 +129,7 @@ void CGProgramWriter::writeSourceCode(std::ostream& os, Program* program)
 
     for (itAtom=atomInstances.begin(); itAtom != atomInstances.end(); ++itAtom)
     {
+        redirectGlobalWrites(os, *itAtom, curFunction->getInputParameters(), program->getParameters());
         writeAtomInstance(os, *itAtom);
     }
 
