@@ -110,10 +110,8 @@ namespace Ogre
 
             // set up scene
             mCompositeMapPlane = mCompositeMapSM->createScreenSpaceRect(true);
-            mCompositeMapPlane->setCorners(-1, 1, 1, -1);
             mCompositeMapPlane->setUVs({0 - hOffset, 0 - vOffset}, {0 - hOffset, 1 - vOffset},
                                        {1 - hOffset, 0 - vOffset}, {1 - hOffset, 1 - vOffset});
-            mCompositeMapPlane->setBoundingBox(AxisAlignedBox::BOX_INFINITE);
 
             mCompositeMapSM->getRootSceneNode()->attachObject(mCompositeMapPlane);
 
