@@ -37,11 +37,10 @@ THE SOFTWARE.
 #include "OgreHighLevelGpuProgram.h"
 #include "OgreRoot.h"
 #include "OgreRenderSystem.h"
-#include "OgreTerrainMaterialShaderHelpers.h"
 #include "OgreTextureManager.h"
 
 #include "OgreShaderGenerator.h"
-#include "OgreTerrainShaderTransform.h"
+#include "OgreTerrainRTShaderSRS.h"
 #include "OgreShaderExIntegratedPSSM3.h"
 
 #include <fstream>
@@ -63,6 +62,29 @@ namespace Ogre
 
         // TODO - check hardware capabilities & use fallbacks if required (more profiles needed)
         setActiveProfile(mProfiles.back());
+
+        using namespace RTShader;
+
+        if (!ShaderGenerator::getSingletonPtr())
+        {
+            LogManager::getSingleton().logError(
+                "TerrainMaterialGeneratorA - Shader generation not possible: RTSS is not initialized.");
+            return;
+        }
+
+        static SubRenderStateFactory* factory = nullptr;
+        if(!factory)
+        {
+            factory = new TerrainTransformFactory;
+            ShaderGenerator::getSingleton().addSubRenderStateFactory(factory);
+            factory = new TerrainSurfaceFactory;
+            ShaderGenerator::getSingleton().addSubRenderStateFactory(factory);
+        }
+
+        mMainRenderState.reset(new RenderState());
+        mMainRenderState->setLightCount(Vector3i(0, 1, 0));
+        mMainRenderState->addTemplateSubRenderStates(
+            {"TerrainTransform", "TerrainSurface", SRS_PER_PIXEL_LIGHTING, SRS_FOG});
     }
     //---------------------------------------------------------------------
     TerrainMaterialGeneratorA::~TerrainMaterialGeneratorA()
@@ -73,7 +95,6 @@ namespace Ogre
     //---------------------------------------------------------------------
     TerrainMaterialGeneratorA::SM2Profile::SM2Profile(TerrainMaterialGenerator* parent, const String& name, const String& desc)
         : Profile(parent, name, desc)
-        , mShaderGen(0)
         , mLayerNormalMappingEnabled(true)
         , mLayerParallaxMappingEnabled(true)
         , mLayerSpecularMappingEnabled(true)
@@ -82,15 +103,12 @@ namespace Ogre
         , mCompositeMapEnabled(true)
         , mReceiveDynamicShadows(true)
         , mPSSM(0)
-        , mDepthShadows(false)
         , mLowLodShadows(false)
     {
-        mShaderGen = OGRE_NEW ShaderHelperGLSL();
     }
     //---------------------------------------------------------------------
     TerrainMaterialGeneratorA::SM2Profile::~SM2Profile()
     {
-        OGRE_DELETE mShaderGen;
     }   
     //---------------------------------------------------------------------
     void TerrainMaterialGeneratorA::SM2Profile::requestOptions(Terrain* terrain)
@@ -178,16 +196,6 @@ namespace Ogre
         }
     }
     //---------------------------------------------------------------------
-    void TerrainMaterialGeneratorA::SM2Profile::setReceiveDynamicShadowsDepth(bool enabled)
-    {
-        if (enabled != mDepthShadows)
-        {
-            mDepthShadows = enabled;
-            mParent->_markChanged();
-        }
-
-    }
-    //---------------------------------------------------------------------
     void TerrainMaterialGeneratorA::SM2Profile::setReceiveDynamicShadowsLowLod(bool enabled)
     {
         if (enabled != mLowLodShadows)
@@ -224,6 +232,21 @@ namespace Ogre
 
     }
     //---------------------------------------------------------------------
+    static int getRequiredLayers(const Terrain* terrain, bool pssm)
+    {
+        int layers = terrain->getLayerCount(); // layer diffusespec
+        if (!terrain->getLayerTextureName(0, 1).empty())
+            layers *= 2; // per layer normalheight
+        layers += 1; // global normal
+        layers += bool(terrain->getGlobalColourMap());
+        layers += bool(terrain->getLightmap());
+        layers += terrain->getBlendTextures().size();
+
+        if(pssm)
+            layers += 3; // 3 shadow textures
+
+        return layers;
+    }
     MaterialPtr TerrainMaterialGeneratorA::SM2Profile::generate(const Terrain* terrain)
     {
         // re-use old material if exists
@@ -244,45 +267,83 @@ namespace Ogre
         // Automatically disable normal & parallax mapping if card cannot handle it
         // We do this rather than having a specific technique for it since it's simpler
         auto rsc = Root::getSingletonPtr()->getRenderSystem()->getCapabilities();
-        if (rsc->getNumTextureUnits() < 9)
+        if (getRequiredLayers(terrain, mPSSM) > rsc->getNumTextureUnits())
         {
             setLayerNormalMappingEnabled(false);
             setLayerParallaxMappingEnabled(false);
+            LogManager::getSingleton().logWarning(
+                "TerrainMaterialGeneratorA: Normal mapping disabled due to lack of texture units");
         }
 
-        addTechnique(mat, terrain, HIGH_LOD);
+        Pass* pass;
+        pass = mat->createTechnique()->createPass();
+        pass->getUserObjectBindings().setUserAny("Terrain", terrain);
+        pass->setSpecular(ColourValue::White);
+        pass->setShininess(32); // user param
+
+        if(mLayerSpecularMappingEnabled)
+        {
+            // we use this to inject our specular map
+            pass->setVertexColourTracking(TVC_SPECULAR);
+        }
+
+        using namespace RTShader;
+        auto mainRenderState = std::make_shared<TargetRenderState>();
+        auto tplRS = static_cast<TerrainMaterialGeneratorA*>(mParent)->getMainRenderState();
+        mainRenderState->setLightCount(tplRS->getLightCount());
+
+        if(auto surface = tplRS->getSubRenderState("TerrainSurface"))
+            surface->setParameter("use_normal_mapping", std::to_string(mLayerNormalMappingEnabled));
+
+        try
+        {
+            mainRenderState->link(*tplRS, pass, pass);
+            auto surface = mainRenderState->getSubRenderState("TerrainSurface");
+            OgreAssert(surface, "TerrainSurface SubRenderState not found");
+            surface->setParameter("use_parallax_mapping", std::to_string(mLayerParallaxMappingEnabled));
+            surface->setParameter("use_specular_mapping", std::to_string(mLayerSpecularMappingEnabled));
+            if(isShadowingEnabled(HIGH_LOD, terrain))
+            {
+                auto pssm = ShaderGenerator::getSingleton().createSubRenderState<IntegratedPSSM3>();
+                if(mPSSM)
+                    pssm->setSplitPoints(mPSSM->getSplitPoints());
+                pssm->preAddToRenderState(mainRenderState.get(), pass, pass);
+                mainRenderState->addSubRenderStateInstance(pssm);
+            }
+            mainRenderState->acquirePrograms(pass);
+        }
+        catch(const std::exception& e)
+        {
+            LogManager::getSingleton().logError(e.what());
+            return nullptr;
+        }
+
+        pass->getUserObjectBindings().setUserAny(TargetRenderState::UserKey, mainRenderState);
 
         // LOD
         if(mCompositeMapEnabled)
         {
-            static TerrainTransformFactory* factory = nullptr;
-            if(!factory)
-            {
-                factory = new TerrainTransformFactory;
-                RTShader::ShaderGenerator::getSingleton().addSubRenderStateFactory(factory);
-            }
-
             Technique* tech = mat->createTechnique();
             tech->setLodIndex(1);
 
-            Pass* pass = tech->createPass();
+            pass = tech->createPass();
             TextureUnitState* tu = pass->createTextureUnitState();
             tu->setTexture(terrain->getCompositeMap());
             tu->setTextureAddressingMode(TAM_CLAMP);
 
             pass->getUserObjectBindings().setUserAny("Terrain", terrain);
 
-            using namespace RTShader;
             auto lod1RenderState = std::make_shared<TargetRenderState>();
             try
             {
-                lod1RenderState->link({"TerrainTransform", "FFP_Colour", "FFP_Texturing", "FFP_Fog"}, pass, pass);
-                if(isShadowingEnabled(LOW_LOD, terrain))
+                lod1RenderState->link({"TerrainTransform", SRS_VERTEX_COLOUR, SRS_TEXTURING, SRS_FOG}, pass, pass);
+                if (isShadowingEnabled(LOW_LOD, terrain))
                 {
                     // light count needed to enable PSSM3
                     lod1RenderState->setLightCount(Vector3i(0, 1, 0));
                     auto pssm = ShaderGenerator::getSingleton().createSubRenderState<IntegratedPSSM3>();
-                    pssm->setSplitPoints(mPSSM->getSplitPoints());
+                    if(mPSSM)
+                        pssm->setSplitPoints(mPSSM->getSplitPoints());
                     pssm->preAddToRenderState(lod1RenderState.get(), pass, pass);
                     lod1RenderState->addSubRenderStateInstance(pssm);
                 }
@@ -324,95 +385,32 @@ namespace Ogre
         // clear everything
         mat->removeAllTechniques();
 
-        addTechnique(mat, terrain, RENDER_COMPOSITE_MAP);
+        using namespace RTShader;
+        auto pass = mat->createTechnique()->createPass();
+        pass->getUserObjectBindings().setUserAny("Terrain", terrain);
 
+        auto compRenderState = std::make_shared<TargetRenderState>();
+        compRenderState->setLightCount(Vector3i(0, 1, 0));
+
+        try
+        {
+            compRenderState->link({SRS_TRANSFORM, "TerrainSurface", SRS_PER_PIXEL_LIGHTING}, pass, pass);
+            auto terrainSurface = compRenderState->getSubRenderState("TerrainSurface");
+            terrainSurface->setParameter("for_composite_map", "true");
+            compRenderState->acquirePrograms(pass);
+            terrainSurface->updateGpuProgramsParams(NULL, NULL, NULL, NULL); // composite map scene manager not registered
+        }
+        catch(const std::exception& e)
+        {
+            LogManager::getSingleton().logError(e.what());
+            return nullptr;
+        }
+
+        pass->getUserObjectBindings().setUserAny(TargetRenderState::UserKey, compRenderState);
         updateParamsForCompositeMap(mat, terrain);
 
         return mat;
 
-    }
-    //---------------------------------------------------------------------
-    void TerrainMaterialGeneratorA::SM2Profile::addTechnique(
-        const MaterialPtr& mat, const Terrain* terrain, TechniqueType tt)
-    {
-        Technique* tech = mat->createTechnique();
-
-        // Only supporting one pass
-        Pass* pass = tech->createPass();
-
-        HighLevelGpuProgramPtr vprog = mShaderGen->generateVertexProgram(this, terrain, tt);
-        HighLevelGpuProgramPtr fprog = mShaderGen->generateFragmentProgram(this, terrain, tt);
-
-        pass->setGpuProgram(GPT_VERTEX_PROGRAM, vprog);
-        pass->setGpuProgram(GPT_FRAGMENT_PROGRAM, fprog);
-
-        SamplerPtr mapSampler = TextureManager::getSingleton().createSampler();
-        mapSampler->setAddressingMode(TAM_CLAMP);
-
-        if (tt == HIGH_LOD || tt == RENDER_COMPOSITE_MAP)
-        {
-            // global normal map
-            TextureUnitState* tu = pass->createTextureUnitState();
-            tu->setTexture(terrain->getTerrainNormalMap());
-            tu->setSampler(mapSampler);
-
-            // global colour map
-            if (terrain->getGlobalColourMapEnabled() && isGlobalColourMapEnabled())
-            {
-                tu = pass->createTextureUnitState();
-                tu->setTexture(terrain->getGlobalColourMap());
-                tu->setSampler(mapSampler);
-            }
-
-            // light map
-            if (isLightmapEnabled())
-            {
-                tu = pass->createTextureUnitState();
-                tu->setTexture(terrain->getLightmap());
-                tu->setSampler(mapSampler);
-            }
-
-            // blend maps
-            uint maxLayers = getMaxLayers(terrain);
-            uint numBlendTextures = std::min<uint8>(Terrain::getBlendTextureCount(maxLayers),
-                                                    terrain->getBlendTextures().size());
-            uint numLayers = std::min(maxLayers, static_cast<uint>(terrain->getLayerCount()));
-            for (uint i = 0; i < numBlendTextures; ++i)
-            {
-                tu = pass->createTextureUnitState();
-                tu->setTexture(terrain->getBlendTextures()[i]);
-                tu->setSampler(mapSampler);
-            }
-
-            // layer textures
-            for (uint i = 0; i < numLayers; ++i)
-            {
-                // diffuse / specular
-                pass->createTextureUnitState(terrain->getLayerTextureName(i, 0));
-                // normal / height
-                if(mLayerNormalMappingEnabled)
-                    pass->createTextureUnitState(terrain->getLayerTextureName(i, 1));
-            }
-
-        }
-
-        // Add shadow textures (always at the end)
-        if (isShadowingEnabled(tt, terrain))
-        {
-            uint numTextures = 1;
-            if (getReceiveDynamicShadowsPSSM())
-            {
-                numTextures = (uint)getReceiveDynamicShadowsPSSM()->getSplitCount();
-            }
-            for (uint i = 0; i < numTextures; ++i)
-            {
-                TextureUnitState* tu = pass->createTextureUnitState();
-                tu->setContentType(TextureUnitState::CONTENT_SHADOW);
-                tu->setTextureAddressingMode(TextureUnitState::TAM_BORDER);
-                tu->setTextureBorderColour(ColourValue::White);
-            }
-        }
-
     }
     //---------------------------------------------------------------------
     bool TerrainMaterialGeneratorA::SM2Profile::isShadowingEnabled(TechniqueType tt, const Terrain* terrain) const
@@ -425,14 +423,25 @@ namespace Ogre
     //---------------------------------------------------------------------
     void TerrainMaterialGeneratorA::SM2Profile::updateParams(const MaterialPtr& mat, const Terrain* terrain)
     {
-        Pass* p = mat->getTechnique(0)->getPass(0);
-        mShaderGen->updateVpParams(this, terrain, HIGH_LOD, p->getVertexProgramParameters());
-        mShaderGen->updateFpParams(this, terrain, HIGH_LOD, p->getFragmentProgramParameters());
+        using namespace RTShader;
+        auto mainRenderState = any_cast<TargetRenderStatePtr>(
+            mat->getTechnique(0)->getPass(0)->getUserObjectBindings().getUserAny(TargetRenderState::UserKey));
+
+        for (auto srs : mainRenderState->getSubRenderStates())
+        {
+            if (auto transform = dynamic_cast<TerrainTransform*>(srs))
+            {
+                transform->updateParams();
+            }
+            if (auto surface = dynamic_cast<TerrainSurface*>(srs))
+            {
+                surface->updateParams();
+            }
+        }
 
         if(!isCompositeMapEnabled())
             return;
 
-        using namespace RTShader;
         auto lod1RenderState = any_cast<TargetRenderStatePtr>(
             mat->getTechnique(1)->getPass(0)->getUserObjectBindings().getUserAny(TargetRenderState::UserKey));
         if (auto transform = lod1RenderState->getSubRenderState("TerrainTransform"))
@@ -443,295 +452,13 @@ namespace Ogre
     //---------------------------------------------------------------------
     void TerrainMaterialGeneratorA::SM2Profile::updateParamsForCompositeMap(const MaterialPtr& mat, const Terrain* terrain)
     {
-        Pass* p = mat->getTechnique(0)->getPass(0);
-        mShaderGen->updateVpParams(this, terrain, RENDER_COMPOSITE_MAP, p->getVertexProgramParameters());
-        mShaderGen->updateFpParams(this, terrain, RENDER_COMPOSITE_MAP, p->getFragmentProgramParameters());
-    }
-    //---------------------------------------------------------------------
-    //---------------------------------------------------------------------
-    HighLevelGpuProgramPtr 
-        ShaderHelper::generateVertexProgram(
-            const SM2Profile* prof, const Terrain* terrain, TechniqueType tt)
-    {
-        HighLevelGpuProgramPtr ret = createVertexProgram(prof, terrain, tt);
+        using namespace RTShader;
+        auto mainRenderState = any_cast<TargetRenderStatePtr>(
+            mat->getTechnique(0)->getPass(0)->getUserObjectBindings().getUserAny(TargetRenderState::UserKey));
 
-        StringStream sourceStr;
-        generateVertexProgramSource(prof, terrain, tt, sourceStr);
-
-        ret->setSource(sourceStr.str());
-        ret->load();
-        defaultVpParams(prof, terrain, tt, ret);
-
-#if OGRE_DEBUG_MODE
-        LogManager::getSingleton().stream(LML_TRIVIAL) << "*** Terrain Vertex Program: " 
-            << ret->getName() << " ***\n" << ret->getSource() << "\n***   ***";
-#endif
-        return ret;
-
-    }
-    //---------------------------------------------------------------------
-    HighLevelGpuProgramPtr 
-    ShaderHelper::generateFragmentProgram(
-        const SM2Profile* prof, const Terrain* terrain, TechniqueType tt)
-    {
-        HighLevelGpuProgramPtr ret = createFragmentProgram(prof, terrain, tt);
-
-        StringStream sourceStr;
-        generateFragmentProgramSource(prof, terrain, tt, sourceStr);
-        ret->setSource(sourceStr.str());
-        ret->load();
-        defaultFpParams(prof, terrain, tt, ret);
-
-#if OGRE_DEBUG_MODE
-        LogManager::getSingleton().stream(LML_TRIVIAL) << "*** Terrain Fragment Program: " 
-            << ret->getName() << " ***\n" << ret->getSource() << "\n*** ***";
-#endif
-        return ret;
-    }
-    //---------------------------------------------------------------------
-    void ShaderHelper::generateFragmentProgramSource(
-        const SM2Profile* prof, const Terrain* terrain, TechniqueType tt, StringStream& outStream)
-    {
-        generateFpHeader(prof, terrain, tt, outStream);
-
-        if (tt != LOW_LOD)
+        if (auto surface = mainRenderState->getSubRenderState("TerrainSurface"))
         {
-            uint maxLayers = prof->getMaxLayers(terrain);
-            uint numLayers = std::min(maxLayers, static_cast<uint>(terrain->getLayerCount()));
-
-            for (uint i = 0; i < numLayers; ++i)
-                generateFpLayer(prof, terrain, tt, i, outStream);
+            static_cast<TerrainSurface*>(surface)->updateParams();
         }
-
-        generateFpFooter(prof, terrain, tt, outStream);
-    }
-    //---------------------------------------------------------------------
-    void ShaderHelper::defaultVpParams(
-        const SM2Profile* prof, const Terrain* terrain, TechniqueType tt, const HighLevelGpuProgramPtr& prog)
-    {
-        GpuProgramParametersSharedPtr params = prog->getDefaultParameters();
-        params->setIgnoreMissingParams(true);
-        params->setNamedAutoConstant("worldMatrix", GpuProgramParameters::ACT_WORLD_MATRIX);
-        params->setNamedAutoConstant("viewProjMatrix", GpuProgramParameters::ACT_VIEWPROJ_MATRIX);
-        params->setNamedAutoConstant("lodMorph", GpuProgramParameters::ACT_CUSTOM, 
-            Terrain::LOD_MORPH_CUSTOM_PARAM);
-        params->setNamedAutoConstant("fogParams", GpuProgramParameters::ACT_FOG_PARAMS);
-
-        if (prof->isShadowingEnabled(tt, terrain))
-        {
-            uint numTextures = 1;
-            if (prof->getReceiveDynamicShadowsPSSM())
-            {
-                numTextures = (uint)prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
-            }
-            for (uint i = 0; i < numTextures; ++i)
-            {
-                params->setNamedAutoConstant("texViewProjMatrix" + StringConverter::toString(i), 
-                    GpuProgramParameters::ACT_TEXTURE_VIEWPROJ_MATRIX, i);
-            }
-        }
-
-        if (terrain->_getUseVertexCompression() && tt != RENDER_COMPOSITE_MAP)
-        {
-            params->setNamedConstant("posIndexToObjectSpace", terrain->getPointTransform());
-        }
-
-        
-        
-    }
-    //---------------------------------------------------------------------
-    void ShaderHelper::defaultFpParams(
-        const SM2Profile* prof, const Terrain* terrain, TechniqueType tt, const HighLevelGpuProgramPtr& prog)
-    {
-        GpuProgramParametersSharedPtr params = prog->getDefaultParameters();
-        params->setIgnoreMissingParams(true);
-
-        params->setNamedAutoConstant("ambient", GpuProgramParameters::ACT_AMBIENT_LIGHT_COLOUR);
-        params->setNamedAutoConstant("lightPosObjSpace", GpuProgramParameters::ACT_LIGHT_POSITION_OBJECT_SPACE, 0);
-        params->setNamedAutoConstant("lightDiffuseColour", GpuProgramParameters::ACT_LIGHT_DIFFUSE_COLOUR, 0);
-        params->setNamedAutoConstant("lightSpecularColour", GpuProgramParameters::ACT_LIGHT_SPECULAR_COLOUR, 0);
-        params->setNamedAutoConstant("eyePosObjSpace", GpuProgramParameters::ACT_CAMERA_POSITION_OBJECT_SPACE);
-        params->setNamedAutoConstant("fogColour", GpuProgramParameters::ACT_FOG_COLOUR);
-
-        if (prof->isShadowingEnabled(tt, terrain))
-        {
-            uint numTextures = 1;
-            if (prof->getReceiveDynamicShadowsPSSM())
-            {
-                PSSMShadowCameraSetup* pssm = prof->getReceiveDynamicShadowsPSSM();
-                numTextures = (uint)pssm->getSplitCount();
-                Vector4 splitPoints;
-                const PSSMShadowCameraSetup::SplitPointList& splitPointList = pssm->getSplitPoints();
-                // Populate from split point 1, not 0, since split 0 isn't useful (usually 0)
-                for (uint i = 1; i < numTextures; ++i)
-                {
-                    splitPoints[i-1] = splitPointList[i];
-                }
-                splitPoints[3] = splitPointList.back();
-                params->setNamedConstant("pssmSplitPoints", splitPoints);
-            }
-
-            if (prof->getReceiveDynamicShadowsDepth())
-            {
-                uint32 samplerOffset = mShadowSamplerStartHi;
-                for (uint i = 0; i < numTextures; ++i)
-                {
-                    params->setNamedAutoConstant("inverseShadowmapSize" + StringConverter::toString(i), 
-                        GpuProgramParameters::ACT_INVERSE_TEXTURE_SIZE, i + samplerOffset);
-                }
-            }
-        }
-
-        // Explicitly bind samplers for GLSL
-        if (mLang == "glsl" || mLang == "glsles")
-        {
-            int numSamplers = 0;
-            if (tt == LOW_LOD)
-            {
-                params->setNamedConstant("compositeMap", (int)numSamplers++);
-            }
-            else
-            {
-                params->setNamedConstant("globalNormal", (int)numSamplers++);
-
-                if (terrain->getGlobalColourMapEnabled() && prof->isGlobalColourMapEnabled())
-                {
-                    params->setNamedConstant("globalColourMap", (int)numSamplers++);
-                }
-                if (prof->isLightmapEnabled())
-                {
-                    params->setNamedConstant("lightMap", (int)numSamplers++);
-                }
-
-                uint maxLayers = prof->getMaxLayers(terrain);
-                uint numBlendTextures = std::min<uint8>(Terrain::getBlendTextureCount(maxLayers),
-                                                        terrain->getBlendTextures().size());
-                uint numLayers = std::min(maxLayers, static_cast<uint>(terrain->getLayerCount()));
-                // Blend textures - sampler definitions
-                for (uint i = 0; i < numBlendTextures; ++i)
-                {
-                    params->setNamedConstant("blendTex" + StringConverter::toString(i), (int)numSamplers++);
-                }
-
-                // Layer textures - sampler definitions & UV multipliers
-                for (uint i = 0; i < numLayers; ++i)
-                {
-                    params->setNamedConstant("difftex" + StringConverter::toString(i), (int)numSamplers++);
-                    if(prof->isLayerNormalMappingEnabled())
-                        params->setNamedConstant("normtex" + StringConverter::toString(i), (int)numSamplers++);
-                }
-            }
-
-            if (prof->isShadowingEnabled(tt, terrain))
-            {
-                uint numShadowTextures = 1;
-                if (prof->getReceiveDynamicShadowsPSSM())
-                    numShadowTextures = (uint)prof->getReceiveDynamicShadowsPSSM()->getSplitCount();
-
-                for (uint i = 0; i < numShadowTextures; ++i)
-                {
-                    if (prof->isShadowingEnabled(tt, terrain))
-                        params->setNamedConstant("shadowMap" + StringConverter::toString(i), (int)numSamplers++);
-                }
-            }
-        }
-    }
-    //---------------------------------------------------------------------
-    void ShaderHelper::updateVpParams(
-        const SM2Profile* prof, const Terrain* terrain, TechniqueType tt, const GpuProgramParametersSharedPtr& params)
-    {
-        params->setIgnoreMissingParams(true);
-
-        if (terrain->_getUseVertexCompression() && tt != RENDER_COMPOSITE_MAP)
-        {
-            Real baseUVScale = 1.0f / (terrain->getSize() - 1);
-            params->setNamedConstant("baseUVScale", baseUVScale);
-        }
-    }
-    //---------------------------------------------------------------------
-    void ShaderHelper::updateFpParams(
-        const SM2Profile* prof, const Terrain* terrain, TechniqueType tt, const GpuProgramParametersSharedPtr& params)
-    {
-        params->setIgnoreMissingParams(true);
-
-        uint maxLayers = prof->getMaxLayers(terrain);
-        uint numLayers = std::min(maxLayers, static_cast<uint>(terrain->getLayerCount()));
-        uint numUVMul = (numLayers + 3) / 4;
-        for (uint i = 0; i < numUVMul; ++i)
-        {
-            Vector4 uvMul(
-                terrain->getLayerUVMultiplier(i * 4), 
-                terrain->getLayerUVMultiplier(i * 4 + 1), 
-                terrain->getLayerUVMultiplier(i * 4 + 2), 
-                terrain->getLayerUVMultiplier(i * 4 + 3) 
-                );
-            params->setNamedConstant("uvMul_" + StringConverter::toString(i), uvMul);
-        }
-
-        // TODO - parameterise this?
-        Vector4 scaleBiasSpecular(0.03, -0.04, 32, 1);
-        params->setNamedConstant("scaleBiasSpecular", scaleBiasSpecular);
-
-    }
-    //---------------------------------------------------------------------
-    const char* ShaderHelper::getChannel(uint idx)
-    {
-        uint rem = idx % 4;
-        switch(rem)
-        {
-        case 0:
-        default:
-            return "r";
-        case 1:
-            return "g";
-        case 2:
-            return "b";
-        case 3:
-            return "a";
-        };
-    }
-    //---------------------------------------------------------------------
-    String ShaderHelper::getVertexProgramName(
-        const SM2Profile* prof, const Terrain* terrain, TechniqueType tt)
-    {
-        String progName = terrain->getMaterialName() + "/sm2/vp";
-        
-        switch(tt)
-        {
-        case HIGH_LOD:
-            progName += "/hlod";
-            break;
-        case LOW_LOD:
-            progName += "/llod";
-            break;
-        case RENDER_COMPOSITE_MAP:
-            progName += "/comp";
-            break;
-        }
-
-        return progName;
-
-    }
-    //---------------------------------------------------------------------
-    String ShaderHelper::getFragmentProgramName(
-        const SM2Profile* prof, const Terrain* terrain, TechniqueType tt)
-    {
-
-        String progName = terrain->getMaterialName() + "/sm2/fp";
-
-        switch(tt)
-        {
-        case HIGH_LOD:
-            progName += "/hlod";
-            break;
-        case LOW_LOD:
-            progName += "/llod";
-            break;
-        case RENDER_COMPOSITE_MAP:
-            progName += "/comp";
-            break;
-        }
-
-        return progName;
     }
 }
