@@ -70,7 +70,7 @@ namespace Ogre {
         mBlankLight.setDiffuseColour(ColourValue::Black);
         mBlankLight.setSpecularColour(ColourValue::Black);
         mBlankLight.setAttenuation(0,1,0,0);
-        mBlankLight._notifyAttached(&mDummyNode);
+        mDummyNode.attachObject(&mBlankLight);
         for(size_t i = 0; i < OGRE_MAX_SIMULTANEOUS_LIGHTS; ++i)
         {
             mTextureViewProjMatrixDirty[i] = true;
@@ -548,9 +548,10 @@ namespace Ogre {
                 static_cast<unsigned short>(index))->_getTexturePtr();
             if (tex)
             {
-                size[0] = static_cast<Real>(tex->getWidth());
-                size[1] = static_cast<Real>(tex->getHeight());
-                size[2] = static_cast<Real>(tex->getDepth());
+                size[0] = static_cast<float>(tex->getWidth());
+                size[1] = static_cast<float>(tex->getHeight());
+                size[2] = static_cast<float>(tex->getDepth());
+                size[3] = static_cast<float>(tex->getNumMipmaps());
             }
         }
 
