@@ -291,6 +291,9 @@ public:
         // Queue passes from mat
         for(auto* pass : technique->getPasses())
         {
+            int tuIdx = 0;
+            for(auto* tu : pass->getTextureUnitStates())
+                rs->_setTextureUnitSettings(tuIdx++, *tu);
             auto params = pass->getGpuProgramParameters(GPT_COMPUTE_PROGRAM);
             params->_updateAutoParams(sm->_getAutoParamDataSource(), GPV_GLOBAL);
             rs->bindGpuProgram(pass->getComputeProgram()->_getBindingDelegate());
@@ -328,12 +331,10 @@ void CompositorInstance::collectPasses(TargetOperation &finalState, const Compos
         {
             if(pass->getFirstRenderQueue() < finalState.currentQueueGroupID)
             {
-                /// Mismatch -- warn user
                 /// XXX We could support repeating the last queue, with some effort
-                LogManager::getSingleton().logWarning("in compilation of Compositor "
-                    +mCompositor->getName()+": Attempt to render queue "+
-                    StringConverter::toString(pass->getFirstRenderQueue())+" after "+
-                    StringConverter::toString(finalState.currentQueueGroupID));
+                LogManager::getSingleton().logError(StringUtil::format(
+                    "Compositor '%s': cannot use first_render_queue %d after last_render_queue %d",
+                    mCompositor->getName().c_str(), pass->getFirstRenderQueue(), finalState.currentQueueGroupID - 1));
             }
 
             RSSetSchemeOperation* setSchemeOperation = 0;
@@ -447,9 +448,6 @@ void CompositorInstance::collectPasses(TargetOperation &finalState, const Compos
             }
             break;
         case CompositionPass::PT_RENDERCUSTOM:
-		
-			finalState.currentQueueGroupID = pass->getFirstRenderQueue();
-		
             RenderSystemOperation* customOperation = CompositorManager::getSingleton().
                 getCustomCompositionPass(pass->getCustomType())->createOperation(this, pass);
             queueRenderSystemOp(finalState, customOperation);
