@@ -51,6 +51,7 @@ namespace Ogre
                 mMaterialLodIndex( 0 ),
                 mDirtyAnimation(true),
                 mTechnSupportsSkeletal( true ),
+                mCameraDistLastUpdateFrameNumber( std::numeric_limits<unsigned long>::max() ),
                 mCachedCamera( 0 ),
                 mTransformSharingDirty(true),
                 mRemoveOwnVertexData(false),
@@ -73,7 +74,7 @@ namespace Ogre
         mName = batchName;
 		if (mCreator != NULL)
 		{
-		    mCustomParams.resize( mCreator->getNumCustomParams() * mInstancesPerBatch, Ogre::Vector4::ZERO );
+		    mCustomParams.resize( mCreator->getNumCustomParams() * mInstancesPerBatch, Vector4f(0) );
 	    }
 		
 	}
@@ -99,22 +100,15 @@ namespace Ogre
 
     void InstanceBatch::_setInstancesPerBatch( size_t instancesPerBatch )
     {
-        if( !mInstancedEntities.empty() )
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALID_STATE, "Instances per batch can only be changed before"
-                        " building the batch.", "InstanceBatch::_setInstancesPerBatch");
-        }
-
+        OgreAssert(mInstancedEntities.empty(),
+                   "Instances per batch can only be changed before building the batch");
         mInstancesPerBatch = instancesPerBatch;
     }
     //-----------------------------------------------------------------------
     bool InstanceBatch::checkSubMeshCompatibility( const SubMesh* baseSubMesh )
     {
-        if( baseSubMesh->operationType != RenderOperation::OT_TRIANGLE_LIST )
-        {
-            OGRE_EXCEPT(Exception::ERR_NOT_IMPLEMENTED, "Only meshes with OT_TRIANGLE_LIST are supported",
-                        "InstanceBatch::checkSubMeshCompatibility");
-        }
+        OgreAssert(baseSubMesh->operationType == RenderOperation::OT_TRIANGLE_LIST,
+                   "Only meshes with OT_TRIANGLE_LIST are supported");
 
         if( !mCustomParams.empty() && mCreator->getInstancingTechnique() != InstanceManager::HWInstancingBasic )
         {
@@ -132,22 +126,16 @@ namespace Ogre
     void InstanceBatch::_updateBounds(void)
     {
         mFullBoundingBox.setNull();
-
-        InstancedEntityVec::const_iterator itor = mInstancedEntities.begin();
-        InstancedEntityVec::const_iterator end  = mInstancedEntities.end();
-
         Real maxScale = 0;
-        while( itor != end )
-        {
-            InstancedEntity* ent = (*itor);
-            //Only increase the bounding box for those objects we know are in the scene
-            if( ent->isInScene() )
-            {
-                maxScale = std::max(maxScale, ent->getMaxScaleCoef());
-                mFullBoundingBox.merge( ent->_getDerivedPosition() );
-            }
 
-            ++itor;
+        for(auto *e : mInstancedEntities)
+        {
+            //Only increase the bounding box for those objects we know are in the scene
+            if(e->isInScene())
+            {
+                maxScale = std::max(maxScale, e->getMaxScaleCoef());
+                mFullBoundingBox.merge( e->_getDerivedPosition() );
+            }
         }
 
         Real addToBound = maxScale * _getMeshReference()->getBoundingSphereRadius();
@@ -159,8 +147,8 @@ namespace Ogre
         if (mParentNode) {
             mParentNode->needUpdate();
         }
-	mBoundsUpdated  = true;
-        mBoundsDirty    = false;
+	    mBoundsUpdated  = true;
+        mBoundsDirty = false;
     }
 
     //-----------------------------------------------------------------------
@@ -202,25 +190,18 @@ namespace Ogre
     //-----------------------------------------------------------------------
     void InstanceBatch::deleteAllInstancedEntities()
     {
-        InstancedEntityVec::const_iterator itor = mInstancedEntities.begin();
-        InstancedEntityVec::const_iterator end  = mInstancedEntities.end();
-
-        while( itor != end )
+        for (auto *e : mInstancedEntities)
         {
-            if( (*itor)->getParentSceneNode() )
-                (*itor)->getParentSceneNode()->detachObject( (*itor) );
-
-            OGRE_DELETE *itor++;
+            if(e->getParentSceneNode() )
+                e->getParentSceneNode()->detachObject(e);
+            OGRE_DELETE e;
         }
     }
     //-----------------------------------------------------------------------
     void InstanceBatch::deleteUnusedInstancedEntities()
     {
-        InstancedEntityVec::const_iterator itor = mUnusedEntities.begin();
-        InstancedEntityVec::const_iterator end  = mUnusedEntities.end();
-
-        while( itor != end )
-            OGRE_DELETE *itor++;
+        for (auto *e : mUnusedEntities)
+            OGRE_DELETE e;
 
         mUnusedEntities.clear();
     }
@@ -231,7 +212,7 @@ namespace Ogre
 
         for( size_t i=0; i<count; i++ )
         {
-            mat3x4[i].setTrans(mat3x4[i].getTrans() - cameraRelativePosition);
+            mat3x4[i].setTrans(mat3x4[i].getTrans() - Vector<3, float>(cameraRelativePosition));
         }
     }
     //-----------------------------------------------------------------------
@@ -275,19 +256,9 @@ namespace Ogre
     //-----------------------------------------------------------------------
     void InstanceBatch::removeInstancedEntity( InstancedEntity *instancedEntity )
     {
-        if( instancedEntity->mBatchOwner != this )
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALIDPARAMS,
-                        "Trying to remove an InstancedEntity from scene created"
-                        " with a different InstanceBatch",
-                        "InstanceBatch::removeInstancedEntity()");
-        }
-        if( !instancedEntity->isInUse() )
-        {
-            OGRE_EXCEPT(Exception::ERR_INVALID_STATE,
-                        "Trying to remove an InstancedEntity that is already removed!",
-                        "InstanceBatch::removeInstancedEntity()");
-        }
+        OgreAssert(instancedEntity->mBatchOwner == this,
+                   "Trying to remove an InstancedEntity from scene created with a different InstanceBatch");
+        OgreAssert(instancedEntity->isInUse(), "Trying to remove an InstancedEntity that is already removed");
 
         if( instancedEntity->getParentSceneNode() )
             instancedEntity->getParentSceneNode()->detachObject( instancedEntity );
@@ -302,20 +273,12 @@ namespace Ogre
     void InstanceBatch::getInstancedEntitiesInUse( InstancedEntityVec &outEntities,
                                                     CustomParamsVec &outParams )
     {
-        InstancedEntityVec::const_iterator itor = mInstancedEntities.begin();
-        InstancedEntityVec::const_iterator end  = mInstancedEntities.end();
-
-        while( itor != end )
-        {
-            if( (*itor)->isInUse() )
-            {
-                outEntities.push_back( *itor );
-
+        for (auto *e : mInstancedEntities) {
+            if (e->isInUse()) {
+                outEntities.push_back(e);
                 for( unsigned char i=0; i<mCreator->getNumCustomParams(); ++i )
-                    outParams.push_back( _getCustomParam( *itor, i ) );
+                    outParams.push_back(_getCustomParam(e, i));
             }
-
-            ++itor;
         }
     }
     //-----------------------------------------------------------------------
@@ -426,14 +389,9 @@ namespace Ogre
 
         //Reassign instance IDs and tell we're the new parent
         uint32 instanceId = 0;
-        InstancedEntityVec::const_iterator itor = mInstancedEntities.begin();
-        InstancedEntityVec::const_iterator end  = mInstancedEntities.end();
-
-        while( itor != end )
-        {
-            (*itor)->mInstanceId = instanceId++;
-            (*itor)->mBatchOwner = this;
-            ++itor;
+        for (auto *e : mInstancedEntities) {
+            e->mInstanceId = instanceId++;
+            e->mBatchOwner = this;
         }
 
         //Recreate unused entities, if there's left space in our container
@@ -446,7 +404,7 @@ namespace Ogre
             InstancedEntity *instance = generateInstancedEntity(i);
             mInstancedEntities.push_back( instance );
             mUnusedEntities.push_back( instance );
-            mCustomParams.push_back( Ogre::Vector4::ZERO );
+            mCustomParams.push_back( Vector4f(0) );
         }
 
         //We've potentially changed our bounds
@@ -604,15 +562,9 @@ namespace Ogre
 
         if( mVisible )
         {
-            if( mMeshReference->hasSkeleton() )
-            {
-                InstancedEntityVec::const_iterator itor = mInstancedEntities.begin();
-                InstancedEntityVec::const_iterator end  = mInstancedEntities.end();
-
-                while( itor != end )    
-                {
-                    mDirtyAnimation |= (*itor)->_updateAnimation();
-                    ++itor;
+            if( mMeshReference->hasSkeleton() ) {
+                for (auto *e : mInstancedEntities) {
+                    mDirtyAnimation |= e->_updateAnimation();
                 }
             }
 
@@ -630,12 +582,12 @@ namespace Ogre
     }
     //-----------------------------------------------------------------------
     void InstanceBatch::_setCustomParam( InstancedEntity *instancedEntity, unsigned char idx,
-                                         const Vector4 &newParam )
+                                         const Vector4f &newParam )
     {
         mCustomParams[instancedEntity->mInstanceId * mCreator->getNumCustomParams() + idx] = newParam;
     }
     //-----------------------------------------------------------------------
-    const Vector4& InstanceBatch::_getCustomParam( InstancedEntity *instancedEntity, unsigned char idx )
+    const Vector4f& InstanceBatch::_getCustomParam( InstancedEntity *instancedEntity, unsigned char idx )
     {
         return mCustomParams[instancedEntity->mInstanceId * mCreator->getNumCustomParams() + idx];
     }
