@@ -146,12 +146,7 @@ ManualObject::ManualObject(const String& name)
 
         if(!material)
         {
-            LogManager::getSingleton().logError("Can't assign material " + materialName +
-                                                  " to the ManualObject " + mName + " because this "
-                                                  "Material does not exist in group " + groupName +
-                                                  ". Have you forgotten to define it in a "
-                                                  ".material script?");
-
+            logMaterialNotFound(materialName, groupName, "ManualObject", mName);
             material = MaterialManager::getSingleton().getDefaultMaterial();
         }
 
