@@ -73,6 +73,12 @@ namespace Ogre {
     //-----------------------------------------------------------------------
     Mesh::~Mesh()
     {
+        if (!HardwareBufferManager::getSingletonPtr()) // LogManager might be also gone already
+        {
+            printf("ERROR: '%s' is being destroyed after HardwareBufferManager. This is a bug in user code.\n", mName.c_str());
+            OgreAssertDbg(false,  "Mesh destroyed after HardwareBufferManager"); // assert in debug mode
+            return; // try not to crash
+        }
         // have to call this here reather than in Resource destructor
         // since calling virtual methods in base destructors causes crash
         unload();
