@@ -73,6 +73,8 @@ mShadowCasterRenderBackFaces(true)
     // set up default shadow camera setup
     mDefaultShadowCameraSetup = DefaultShadowCameraSetup::create();
 
+    mCullCameraSetup = DefaultShadowCameraSetup::create();
+
     // init shadow texture count per type.
     mShadowTextureCountPerType[Light::LT_POINT] = 1;
     mShadowTextureCountPerType[Light::LT_DIRECTIONAL] = 1;
@@ -635,11 +637,8 @@ void SceneManager::ShadowRenderer::ensureShadowTexturesCreated()
         size_t __i = 0;
 
         // Recreate shadow textures
-        for (ShadowTextureList::iterator i = mShadowTextures.begin();
-            i != mShadowTextures.end(); ++i, ++__i)
+        for (auto& shadowTex : mShadowTextures)
         {
-            const TexturePtr& shadowTex = *i;
-
             // Camera names are local to SM
             String camName = shadowTex->getName() + "Cam";
 
@@ -653,9 +652,18 @@ void SceneManager::ShadowRenderer::ensureShadowTexturesCreated()
             // in prepareShadowTextures to coexist with multiple SMs
             Camera* cam = mSceneManager->createCamera(camName);
             cam->setAspectRatio((Real)shadowTex->getWidth() / (Real)shadowTex->getHeight());
-            mSceneManager->getRootSceneNode()->createChildSceneNode()->attachObject(cam);
+            auto camNode = mSceneManager->getRootSceneNode()->createChildSceneNode();
+            camNode->attachObject(cam);
             mShadowTextureCameras.push_back(cam);
 
+            // use separate culling camera, in case a focused shadow setup is used
+            // in which case we want to keep the original light frustum for culling
+            Camera* cullCam = mSceneManager->createCamera(camName+"/Cull");
+            cullCam->setAspectRatio((Real)shadowTex->getWidth() / (Real)shadowTex->getHeight());
+            cam->setCullingFrustum(cullCam);
+            camNode->attachObject(cullCam);
+
+
             // Create a viewport, if not there already
             if (shadowRTT->getNumViewports() == 0)
             {
@@ -682,8 +690,7 @@ void SceneManager::ShadowRenderer::ensureShadowTexturesCreated()
                 mNullShadowTexture = ShadowTextureManager::getSingleton().getNullShadowTexture(
                     mShadowTextureConfigList[0].format);
             }
-
-
+            ++__i;
         }
         mShadowTextureConfigDirty = false;
     }
@@ -695,7 +702,11 @@ void SceneManager::ShadowRenderer::destroyShadowTextures(void)
     for (auto cam : mShadowTextureCameras)
     {
         mSceneManager->getRootSceneNode()->removeAndDestroyChild(cam->getParentSceneNode());
+
         // Always destroy camera since they are local to this SM
+        if(auto cullcam = dynamic_cast<Camera*>(cam->getCullingFrustum()))
+            mSceneManager->destroyCamera(cullcam);
+
         mSceneManager->destroyCamera(cam);
     }
     mShadowTextures.clear();
@@ -752,6 +763,7 @@ void SceneManager::ShadowRenderer::prepareShadowTextures(Camera* cam, Viewport*
     ci = mShadowTextureCameras.begin();
     mShadowTextureIndexLightList.clear();
     size_t shadowTextureIndex = 0;
+
     for (i = lightList->begin(), si = mShadowTextures.begin(); i != iend && si != siend; ++i)
     {
         Light* light = *i;
@@ -760,6 +772,8 @@ void SceneManager::ShadowRenderer::prepareShadowTextures(Camera* cam, Viewport*
         if (!light->getCastShadows())
             continue;
 
+        mDestRenderSystem->_setDepthClamp(light->getType() == Light::LT_DIRECTIONAL);
+
         // texture iteration per light.
         size_t textureCountPerLight = mShadowTextureCountPerType[light->getType()];
         for (size_t j = 0; j < textureCountPerLight && si != siend; ++j)
@@ -785,6 +799,11 @@ void SceneManager::ShadowRenderer::prepareShadowTextures(Camera* cam, Viewport*
             if (light->getType() != Light::LT_DIRECTIONAL)
                 texCam->getParentSceneNode()->setPosition(light->getDerivedPosition());
 
+            // also update culling camera
+            auto cullCam = dynamic_cast<Camera*>(texCam->getCullingFrustum());
+            cullCam->_notifyViewport(shadowView);
+            mCullCameraSetup->getShadowCamera(mSceneManager, cam, vp, light, cullCam, j);
+
             // Use the material scheme of the main viewport
             // This is required to pick up the correct shadow_caster_material and similar properties.
             shadowView->setMaterialScheme(vp->getMaterialScheme());
@@ -815,6 +834,8 @@ void SceneManager::ShadowRenderer::prepareShadowTextures(Camera* cam, Viewport*
             ++ci; // next camera
         }
 
+        mDestRenderSystem->_setDepthClamp(false);
+
         // set the first shadow texture index for this light.
         mShadowTextureIndexLightList.push_back(shadowTextureIndex);
         shadowTextureIndex += textureCountPerLight;
@@ -925,14 +946,8 @@ void SceneManager::ShadowRenderer::renderShadowVolumesToStencil(const Light* lig
         light->_getNearClipVolume(camera);
 
     // Now iterate over the casters and render
-    ShadowCasterList::const_iterator si, siend;
-    siend = casters.end();
-
-
-    // Now iterate over the casters and render
-    for (si = casters.begin(); si != siend; ++si)
+    for (auto *caster : casters)
     {
-        ShadowCaster* caster = *si;
         bool zfailAlgo = camera->isCustomNearClipPlaneEnabled();
         unsigned long flags = 0;
 
@@ -1508,17 +1523,16 @@ SceneManager::ShadowRenderer::getShadowCasterBoundsInfo( const Light* light, siz
 
     // find light
     unsigned int foundCount = 0;
-    ShadowCamLightMapping::const_iterator it;
-    for ( it = mShadowCamLightMapping.begin() ; it != mShadowCamLightMapping.end(); ++it )
+    for (auto& m : mShadowCamLightMapping)
     {
-        if ( it->second == light )
+        if (m.second == light )
         {
             if (foundCount == iteration)
             {
                 // search the camera-aab list for the texture cam
-                auto camIt = mSceneManager->mCamVisibleObjectsMap.find( it->first );
+                auto camIt = mSceneManager->mCamVisibleObjectsMap.find(m.first);
 
-                if ( camIt == mSceneManager->mCamVisibleObjectsMap.end() )
+                if (camIt == mSceneManager->mCamVisibleObjectsMap.end())
                 {
                     return nullBox;
                 }
@@ -1830,12 +1844,10 @@ SceneManager::ShadowRenderer::findShadowCastersForLight(const Light* light, cons
 void SceneManager::ShadowRenderer::fireShadowTexturesUpdated(size_t numberOfShadowTextures)
 {
     ListenerList listenersCopy = mListeners;
-    ListenerList::iterator i, iend;
 
-    iend = listenersCopy.end();
-    for (i = listenersCopy.begin(); i != iend; ++i)
+    for (auto *l : listenersCopy)
     {
-        (*i)->shadowTexturesUpdated(numberOfShadowTextures);
+        l->shadowTexturesUpdated(numberOfShadowTextures);
     }
 }
 //---------------------------------------------------------------------
@@ -1851,12 +1863,9 @@ void SceneManager::ShadowRenderer::fireShadowTexturesPreCaster(Light* light, Cam
 void SceneManager::ShadowRenderer::fireShadowTexturesPreReceiver(Light* light, Frustum* f)
 {
     ListenerList listenersCopy = mListeners;
-    ListenerList::iterator i, iend;
-
-    iend = listenersCopy.end();
-    for (i = listenersCopy.begin(); i != iend; ++i)
+    for (auto *l : listenersCopy)
     {
-        (*i)->shadowTextureReceiverPreViewProj(light, f);
+        l->shadowTextureReceiverPreViewProj(light, f);
     }
 }
 void SceneManager::ShadowRenderer::sortLightsAffectingFrustum(LightList& lightList) const
