@@ -63,6 +63,7 @@ extern "C" {
 #include "OgreFileSystem.h"
 #include "OgreFrustum.h"
 #include "OgreHardwareBufferManager.h"
+#include "OgreLight.h"
 #include "OgreLog.h"
 #include "OgreLogManager.h"
 #include "OgreManualObject.h"
@@ -84,6 +85,8 @@ extern "C" {
 #include "OgreQuaternion.h"
 #include "OgreRadixSort.h"
 #include "OgreRay.h"
+#include "OgreRectangle2D.h"
+#include "OgreBuiltinMovableFactories.h"
 #include "OgreRenderSystem.h"
 #include "OgreResourceGroupManager.h"
 #include "OgreResource.h"
@@ -125,4 +128,10 @@ extern "C" {
 #define OGRE_IGNORE_DEPRECATED_END _Pragma("GCC diagnostic pop")
 #endif
 
+namespace Ogre
+{
+void logMaterialNotFound(const String& name, const String& groupName, const String& destType, const String& destName,
+                         LogMessageLevel lml = LML_CRITICAL);
+}
+
 #endif 
