@@ -134,23 +134,18 @@ namespace Ogre {
                 size_t texUnit = 0;
                 for(const TextureUnitState* tex : currPass->getTextureUnitStates())
                 {
-                    String err;
+                    const char* err = 0;
                     if ((tex->getTextureType() == TEX_TYPE_3D) && !caps->hasCapability(RSC_TEXTURE_3D))
-                    {
-                        err = "Volume textures";
-                    }
+                        err = "Volume";
 
-                    if ((tex->getTextureType() == TEX_TYPE_2D_ARRAY) &&
-                        !caps->hasCapability(RSC_TEXTURE_2D_ARRAY))
-                    {
-                        err = "Array textures";
-                    }
+                    if ((tex->getTextureType() == TEX_TYPE_2D_ARRAY) && !caps->hasCapability(RSC_TEXTURE_2D_ARRAY))
+                        err = "Array";
 
-                    if (!err.empty())
+                    if (err)
                     {
                         // Fail
                         compileErrors << "Pass " << passNum << " Tex " << texUnit << ": " << err
-                                      << " not supported by current environment.";
+                                      << " textures not supported by RenderSystem";
                         return false;
                     }
                     ++texUnit;
