@@ -121,6 +121,7 @@ namespace Ogre {
         : mCurrentFrame(0)
         , mAnimDuration(0)
         , mTextureCoordSetIndex(0)
+        , mUnorderedAccessMipLevel(-1)
         , mGamma(1)
         , mUMod(0)
         , mVMod(0)
@@ -164,6 +165,7 @@ namespace Ogre {
         : mCurrentFrame(0)
         , mAnimDuration(0)
         , mTextureCoordSetIndex(0)
+        , mUnorderedAccessMipLevel(-1)
         , mGamma(1)
         , mUMod(0)
         , mVMod(0)
@@ -1021,10 +1023,35 @@ namespace Ogre {
         return static_pointer_cast<Texture>(res.first);
     }
     //-----------------------------------------------------------------------
+    bool TextureUnitState::checkTexCalcSettings(const TexturePtr& tex) const
+    {
+        if(mContentType != TextureUnitState::CONTENT_NAMED)
+            return true; // can only check normal textures
+
+        String err;
+        auto texCalc = _deriveTexCoordCalcMethod();
+        if ((texCalc == TEXCALC_ENVIRONMENT_MAP_PLANAR || texCalc == TEXCALC_ENVIRONMENT_MAP) &&
+            getTextureType() != TEX_TYPE_2D)
+        {
+            err = "env_map setting requires a 2d texture";
+        }
+        else if ((texCalc == TEXCALC_ENVIRONMENT_MAP_NORMAL || texCalc == TEXCALC_ENVIRONMENT_MAP_REFLECTION) &&
+                 getTextureType() != TEX_TYPE_CUBE_MAP)
+        {
+            err = "env_map setting requires a cubic texture";
+        }
+        if(err.empty())
+            return true;
+
+        String msg = err+", but '"+tex->getName()+"' is not. Texture layer will be blank";
+        LogManager::getSingleton().logError(msg);
+        mTextureLoadFailed = true;
+        return false;
+    }
     void TextureUnitState::ensurePrepared(size_t frame) const
     {
         const TexturePtr& tex = mFramePtrs[frame];
-        if (!tex || mTextureLoadFailed)
+        if (!tex || mTextureLoadFailed || !checkTexCalcSettings(tex))
             return;
 
         tex->setGamma(mGamma);
@@ -1044,11 +1071,14 @@ namespace Ogre {
     void TextureUnitState::ensureLoaded(size_t frame) const
     {
         const TexturePtr& tex = mFramePtrs[frame];
-        if (!tex || mTextureLoadFailed)
+        if (!tex || mTextureLoadFailed || !checkTexCalcSettings(tex))
             return;
 
         tex->setGamma(mGamma);
 
+        if(mUnorderedAccessMipLevel > -1)
+            tex->setUsage(HBU_GPU_ONLY | TU_UNORDERED_ACCESS);
+
         try {
             tex->load();
         }
@@ -1260,4 +1290,44 @@ namespace Ogre {
 
         return mSampler;
     }
+
+    TexCoordCalcMethod TextureUnitState::_deriveTexCoordCalcMethod() const
+    {
+        TexCoordCalcMethod texCoordCalcMethod = TEXCALC_NONE;
+        for (const auto& effi : mEffects)
+        {
+            switch (effi.second.type)
+            {
+            case ET_ENVIRONMENT_MAP:
+                if (effi.second.subtype == ENV_CURVED)
+                {
+                    texCoordCalcMethod = TEXCALC_ENVIRONMENT_MAP;
+                }
+                else if (effi.second.subtype == ENV_PLANAR)
+                {
+                    texCoordCalcMethod = TEXCALC_ENVIRONMENT_MAP_PLANAR;
+                }
+                else if (effi.second.subtype == ENV_REFLECTION)
+                {
+                    texCoordCalcMethod = TEXCALC_ENVIRONMENT_MAP_REFLECTION;
+                }
+                else if (effi.second.subtype == ENV_NORMAL)
+                {
+                    texCoordCalcMethod = TEXCALC_ENVIRONMENT_MAP_NORMAL;
+                }
+                break;
+            case ET_UVSCROLL:
+            case ET_USCROLL:
+            case ET_VSCROLL:
+            case ET_ROTATE:
+            case ET_TRANSFORM:
+                break;
+            case ET_PROJECTIVE_TEXTURE:
+                texCoordCalcMethod = TEXCALC_PROJECTIVE_TEXTURE;
+                break;
+            }
+        }
+
+        return texCoordCalcMethod;
+    }
 }
