@@ -34,12 +34,7 @@ The wiki article explaining this demo can be found here :
 
 #include "SdkSample.h"
 
-#if OGRE_PLATFORM == OGRE_PLATFORM_WIN32
-#define WIN32_LEAN_AND_MEAN
-#include "windows.h"
-#endif
-
-#include "SharedData.h"
+#include "DeferredShading.h"
 #include "OgreCompositorInstance.h"
 #include "OgreSceneManager.h"
 #include "OgreSceneNode.h"
@@ -58,6 +53,7 @@ const ColourValue SAMPLE_COLORS[] =
 class _OgreSampleClassExport Sample_DeferredShading : public SdkSample, public RenderTargetListener
 {
 protected:
+    Light* mMainLight;
     DeferredShadingSystem *mSystem;
     SelectMenu* mDisplayModeMenu;
     
@@ -73,10 +69,8 @@ public:
 
 protected:
     
-    void cleanupContent(void)
+    void cleanupContent(void) override
     {
-        delete ( SharedData::getSingletonPtr() );
-        
         delete mSystem;
     }
     
@@ -98,23 +92,21 @@ protected:
         mDisplayModeMenu->addItem("Debug depth / specular");
     }
     
-    void itemSelected(SelectMenu* menu)
+    void itemSelected(SelectMenu* menu) override
     {
         //Options are aligned with the mode enum
-        SharedData::getSingleton().iSystem->setMode(
-                                                    (DeferredShadingSystem::DSMode)menu->getSelectionIndex());
+        mSystem->setMode((DeferredShadingSystem::DSMode)menu->getSelectionIndex());
     }
     
-    void checkBoxToggled(CheckBox* box)
+    void checkBoxToggled(CheckBox* box) override
     {
         if (box->getName() == "SSAO")
         {
-            SharedData::getSingleton().iSystem->setSSAO(box->isChecked());
+            mSystem->setSSAO(box->isChecked());
         }
         else if (box->getName() == "GlobalLight")
         {
-            SharedData::getSingleton().iGlobalActivate = box->isChecked();
-            SharedData::getSingleton().iMainLight->setVisible(box->isChecked());
+            mMainLight->setVisible(box->isChecked());
         }
         else if (box->getName() == "Shadows")
         {
@@ -124,7 +116,7 @@ protected:
         }
         else if (box->getName() == "DeferredShading")
         {
-            SharedData::getSingleton().iSystem->setActive(box->isChecked());
+            mSystem->setActive(box->isChecked());
         }
     }
     
@@ -233,22 +225,8 @@ protected:
         
     }
 
-    StringVector getRequiredPlugins()
+    void testCapabilities(const RenderSystemCapabilities* caps) override
     {
-        StringVector names;
-        if (!GpuProgramManager::getSingleton().isSyntaxSupported("glsles") && !GpuProgramManager::getSingleton().isSyntaxSupported("glsl150"))
-            names.push_back("Cg Program Manager");
-        return names;
-    }
-
-    void testCapabilities(const RenderSystemCapabilities* caps)
-    {
-        if (!caps->hasCapability(RSC_VERTEX_PROGRAM) || !(caps->hasCapability(RSC_FRAGMENT_PROGRAM)))
-        {
-            OGRE_EXCEPT(Exception::ERR_NOT_IMPLEMENTED, "Your card does not support vertex and fragment programs, so cannot "
-                        "run this demo. Sorry!", 
-                        "DeferredShading::testCapabilities");
-        }
         if (caps->getNumMultiRenderTargets()<2)
         {
             OGRE_EXCEPT(Exception::ERR_NOT_IMPLEMENTED, "Your card does not support at least two simultaneous render targets, so cannot "
@@ -256,22 +234,13 @@ protected:
                         "DeferredShading::testCapabilities");
         }
 
-        if (!GpuProgramManager::getSingleton().isSyntaxSupported("vs_1_1") &&
-            !GpuProgramManager::getSingleton().isSyntaxSupported("arbvp1") &&
-            !GpuProgramManager::getSingleton().isSyntaxSupported("vs_4_0") &&
-            !GpuProgramManager::getSingleton().isSyntaxSupported("glsl300es") &&
-            !GpuProgramManager::getSingleton().isSyntaxSupported("glsl150"))
-        {
-            OGRE_EXCEPT(Exception::ERR_NOT_IMPLEMENTED, "Your graphics card does not support advanced vertex"
-                        " programs, so you cannot run this sample. Sorry!", "DeferredShading::testCapabilities");
-        }
+        requireMaterial("DeferredShading/AmbientLight");
     }
 
     // Just override the mandatory create scene method
-    void setupContent(void)
+    void setupContent(void) override
     {
         mCameraMan->setTopSpeed(20.0);
-        new SharedData();
         mSystem = 0;
 
         // Set ambient light
@@ -282,12 +251,15 @@ protected:
         Light* l1 = mSceneMgr->createLight();
         l1->setType(Light::LT_DIRECTIONAL);
         l1->setDiffuseColour(0.5f, 0.45f, 0.1f);
-        l1->setDirection(1, -0.5, -0.2);
         l1->setShadowFarClipDistance(250);
         l1->setShadowFarDistance(75);
         //Turn this on to have the directional light cast shadows
         l1->setCastShadows(false);
         
+        auto ln = mSceneMgr->getRootSceneNode()->createChildSceneNode();
+        ln->setDirection(Vector3(1, -0.5, -0.2));
+        ln->attachObject(l1);
+
         mCameraNode->setPosition(25, 5, 0);
         mCameraNode->lookAt(Vector3::ZERO, Node::TS_PARENT);
         mCamera->setFarClipDistance(1000.0);
@@ -295,16 +267,9 @@ protected:
         setDragLook(true);
         
         mSystem = new DeferredShadingSystem(mWindow->getViewport(0), mSceneMgr, mCamera);
-        SharedData::getSingleton().iSystem = mSystem;
         mSystem->initialize();
         
-        // safely setup application's (not postfilter!) shared data
-        SharedData::getSingleton().iCamera = mCamera;
-        SharedData::getSingleton().iRoot = mRoot;
-        SharedData::getSingleton().iWindow = mWindow;
-        SharedData::getSingleton().iActivate = true;
-        SharedData::getSingleton().iGlobalActivate = true;
-        SharedData::getSingleton().iMainLight = l1;
+        mMainLight = l1;
         
         //Create the scene
         // Create "root" node
@@ -417,9 +382,6 @@ protected:
             ent->setVisible(true);
         }       
         
-        // Store nodes for hiding/showing
-        SharedData::getSingleton().mLightNodes = nodes;
-        
         // Do some animation for node a-f
         // Generate helix structure
         float seconds_per_station = 1.0f;
